@@ -1,5 +1,7 @@
 """
-Main interface for backup service literal definitions.
+Type annotations for backup service literal definitions.
+
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_backup/literals.html)
 
 Usage::
 
